@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """ A module to perform measurements on the RIPE Atlas
-<http://atlas.ripe.net/> probes using the UDM (User Defined
+<https://atlas.ripe.net/> probes using the UDM (User Defined
 Measurements) creation API.
 
 Authorization key is expected in $HOME/.atlas/auth or have to be
@@ -12,7 +12,8 @@ Stéphane Bortzmeyer <stephane+frama@bortzmeyer.org>
 
 """
 
-VERSION = '1.1.6'
+# WARNING: if you modify it here, also change setup.py https://packaging.python.org/guides/single-sourcing-package-version/#single-sourcing-the-version
+VERSION = '1.1.8'
 
 import os
 import json
@@ -507,7 +508,7 @@ class Measurement():
                 except urllib.error.HTTPError as e:
                     if e.code != 404: # Yes, we may have no result file at
                         # all for some time
-                        raise ResultError(str(e.code) + " " + e.reason + " " + e.read())
+                        raise ResultError(str(e.code) + " " + e.reason + " " + str(e.read()))
                 except urllib.error.URLError as e:
                     raise ResultError("Reason \"%s\"" % \
                                              (e.reason))
